@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.12-4996.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
 #ifndef YY_YY_GRAMMAR_H_INCLUDED
 # define YY_YY_GRAMMAR_H_INCLUDED
-/* Enabling traces.  */
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,75 +40,74 @@
 extern int yydebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     T_SERVICE = 258,
-     T_PORT = 259,
-     T_EXEC = 260,
-     T_PROTO = 261,
-     T_UDP = 262,
-     T_TCP = 263,
-     T_UID = 264,
-     T_GID = 265,
-     T_BACKLOG = 266,
-     T_INSTANCES = 267,
-     T_WAIT = 268,
-     T_DEFAULT = 269,
-     T_NICE = 270,
-     T_INTERFACE = 271,
-     T_ANY = 272,
-     T_FISH = 273,
-     T_CHROOT = 274,
-     T_SERVER = 275,
-     T_DIR = 276,
-     T_RPC = 277,
-     T_VERSION = 278,
-     T_NAME = 279,
-     T_WRAP = 280,
-     T_CAPS = 281,
-     T_FAMILY = 282,
-     T_IPV4 = 283,
-     T_IPV6 = 284,
-     T_INITGROUPS = 285,
-     T_BANNER = 286,
-     T_ECHO = 287,
-     T_DISCARD = 288,
-     T_FILTER = 289,
-     T_CHARGEN = 290,
-     T_LOOPBACK = 291,
-     T_ENABLED = 292,
-     T_RLIMIT = 293,
-     T_LIM_CPU = 294,
-     T_LIM_FSIZE = 295,
-     T_LIM_DATA = 296,
-     T_LIM_STACK = 297,
-     T_LIM_CORE = 298,
-     T_LIM_RSS = 299,
-     T_LIM_NPROC = 300,
-     T_LIM_NOFILE = 301,
-     T_LIM_MEMLOCK = 302,
-     T_LIM_INFINITY = 303,
-     T_SOFT = 304,
-     T_HARD = 305,
-     T_YES = 306,
-     T_NO = 307,
-     T_LOG = 308,
-     T_PIPE = 309,
-     T_SYSLOG = 310,
-     T_PATH = 311,
-     T_MODE = 312,
-     T_ACCEPT = 313,
-     T_DENY = 314,
-     T_CLOSE = 315,
-     T_EXIT = 316,
-     T_NUMERIC = 317,
-     T_QSTRING = 318,
-     T_IPADDR = 319
-   };
+  enum yytokentype
+  {
+    T_SERVICE = 258,
+    T_PORT = 259,
+    T_EXEC = 260,
+    T_PROTO = 261,
+    T_UDP = 262,
+    T_TCP = 263,
+    T_UID = 264,
+    T_GID = 265,
+    T_BACKLOG = 266,
+    T_INSTANCES = 267,
+    T_WAIT = 268,
+    T_DEFAULT = 269,
+    T_NICE = 270,
+    T_INTERFACE = 271,
+    T_ANY = 272,
+    T_FISH = 273,
+    T_CHROOT = 274,
+    T_SERVER = 275,
+    T_DIR = 276,
+    T_RPC = 277,
+    T_VERSION = 278,
+    T_NAME = 279,
+    T_WRAP = 280,
+    T_CAPS = 281,
+    T_FAMILY = 282,
+    T_IPV4 = 283,
+    T_IPV6 = 284,
+    T_INITGROUPS = 285,
+    T_BANNER = 286,
+    T_ECHO = 287,
+    T_DISCARD = 288,
+    T_FILTER = 289,
+    T_CHARGEN = 290,
+    T_LOOPBACK = 291,
+    T_ENABLED = 292,
+    T_RLIMIT = 293,
+    T_LIM_CPU = 294,
+    T_LIM_FSIZE = 295,
+    T_LIM_DATA = 296,
+    T_LIM_STACK = 297,
+    T_LIM_CORE = 298,
+    T_LIM_RSS = 299,
+    T_LIM_NPROC = 300,
+    T_LIM_NOFILE = 301,
+    T_LIM_MEMLOCK = 302,
+    T_LIM_INFINITY = 303,
+    T_SOFT = 304,
+    T_HARD = 305,
+    T_YES = 306,
+    T_NO = 307,
+    T_LOG = 308,
+    T_PIPE = 309,
+    T_SYSLOG = 310,
+    T_PATH = 311,
+    T_MODE = 312,
+    T_ACCEPT = 313,
+    T_DENY = 314,
+    T_CLOSE = 315,
+    T_EXIT = 316,
+    T_NUMERIC = 317,
+    T_QSTRING = 318,
+    T_IPADDR = 319
+  };
 #endif
 /* Tokens.  */
 #define T_SERVICE 258
@@ -174,13 +173,12 @@ extern int yydebug;
 #define T_QSTRING 318
 #define T_IPADDR 319
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+
+union YYSTYPE
 {
-/* Line 2053 of yacc.c  */
-#line 107 "grammar.y"
+#line 107 "grammar.y" /* yacc.c:1909  */
 
 	long num;
 	char *cp;
@@ -190,29 +188,17 @@ typedef union YYSTYPE
 	struct opmeta *opm;
 	rlim_t rl;
 
+#line 192 "grammar.h" /* yacc.c:1909  */
+};
 
-/* Line 2053 of yacc.c  */
-#line 196 "grammar.h"
-} YYSTYPE;
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
 int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 #endif /* !YY_YY_GRAMMAR_H_INCLUDED  */
