@@ -53,7 +53,7 @@ void read_hook(int, rl_opcode_t *, struct rl_instance *);
 void read_unhook(int);
 void write_hook(int, rl_opcode_t *, struct rl_instance *);
 void write_unhook(int);
-void all_unhook();
+void all_unhook(void);
 
 void listeners_clear(int);
 void listeners_set(int);
