@@ -5,15 +5,15 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-void rl_siginit();
-void rls_block();
-void rls_unblock();
+void rl_siginit(void);
+void rls_block(void);
+void rls_unblock(void);
 
 #define RL_MAX(a,b) ((a) > (b) ? (a) : (b))
 
 extern volatile int rls_need_parse;					/* SIGHUP flag */
 extern volatile int rls_term_recv;					/* SIGTERM or SIGINT flag */
-extern volatile struct pidtab *rls_reaped;
+extern struct pidtab * volatile rls_reaped;
 
 #endif /* !H_SIGNALS */
 
